import greenfoot.*;  // （World、Actor、GreenfootImage、GreenfootSound、Greenfoot及MouseInfo）

/**
 * Pac-Man 小精靈的演員。
 * 
 * @author 依瑪貓
 * @version 2012/2/2
 */
public abstract class Mover extends Actor {
    
    /** 演員面對的方向， 0 是上， 1 是右， 2 是下， 3 是左。 */
    private int direction = 3;
    
    /** 第幾步。 */
    private int steps = 0;
    
    /**
     * 設定演員前進的方向， 0 是上， 1 是右， 2 是下， 3 是左。
     * 
     * @param newDirection 演員前進的方向
     */
    public void setDirection(int newDirection) {
        direction = newDirection;
    }
    
    /**
     * 取得演員前進的方向， 0 是上， 1 是右， 2 是下， 3 是左。
     * 
     * @return 演員前進的方向
     */
    public int getDirection() {
        return direction;
    }
    
    /**
     * 有沒有看到別的演員。
     * 
     * @param cls 別的演員的類別。
     * @return 有沒有看到別的演員。
     */
    public boolean canSee(Class cls) {
        if (getOneIntersectingObject(cls) == null) {
            return false;
        } else {
            return true;
        }
    }
    
    /**
     * 吃掉別的演員。
     * 
     * @param cls 別的演員的類別。
     */
    public void eat(Class cls) {
        Actor actor = getOneIntersectingObject(cls);
        if (actor != null) {
            getWorld().removeObject(actor);
        }
    }
    
    /**
     * 小精靈移動。
     * 
     */
    public void move() {
        
        switch (direction) {
        // 向上。
        case 0:
            if (getY() > 0) {
                setLocation(getX(), getY() - 1);
            }
            break;
        // 向右。
        case 1:
            if (getX() < getWorld().getWidth() - 1) {
                setLocation(getX() + 1, getY());
            }
            break;
        // 向下。
        case 2:
            if (getY() < getWorld().getHeight() - 1) {
                setLocation(getX(), getY() + 1);
            }
            break;
        // 向左。
        case 3:
            if (getX() > 0) {
                setLocation(getX() - 1, getY());
            }
            break;
        }
    }
    
    public boolean atWorldEdge() {
        switch (direction) {
        // 向上。
        case 0:
            if (getY() > 0) {
                return false;
            }
            return true;
        // 向右。
        case 1:
            if (getX() < getWorld().getWidth() - 1) {
                return false;
            }
            return true;
        // 向下。
        case 2:
            if (getY() < getWorld().getHeight() - 1) {
                return false;
            }
            return true;
        // 向左。
        case 3:
            if (getX() > 0) {
                return false;
            }
            return true;
        }
        return false;
    }
}